@@ -1,5 +1,5 @@
-$DEF_VERSION = $VERSION_D = "0.2.6";
-$version_key = "Bucktooth/0.2.6";
+$DEF_VERSION = $VERSION_D = "0.2.7";
+$version_key = "Bucktooth/0.2.7";
 $my_version_key = 0;
 
 sub detaint { # sigh
@@ -32,9 +32,9 @@ sub wherecheck {
 
 	print stdout "$prompt ... ";
 	foreach(@paths) {
-		if (-r "$_/$filename") {
-			$setv = "$_/$filename";
-			1 while $setv =~ s#//#/#;
+		$setv = "$_/$filename";
+		1 while $setv =~ s#//#/#;
+		if (-r $setv) {
 			print "$setv\n";
 			last;
 		}
